@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: address.py 1229 2011-01-29 17:07:16Z icemac $
+# $Id: address.py 1293 2011-08-10 18:41:45Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import icemac.addressbook.entities
@@ -138,6 +138,25 @@ def phone_number_title(tel):
     return title
 
 
+def normalize_phone_number(number, country_code):
+    """Normalize a phone number to E.123 notation (but without spaces).
+
+    See: http://de.wikipedia.org/wiki/E.123
+
+    """
+    digits = ''.join(x for x in number if x.isdigit())
+    if digits.startswith('00'):
+        # old writing of numbers abroad
+        return digits.replace('00', '+', 1)
+    if not country_code:
+        # without country_code no further normalization is possible
+        return digits
+    if digits.startswith('0'):
+        # normalize numbers without country code
+        return digits.replace('0', country_code, 1)
+    return '+' + digits
+
+
 def default_attrib_name_to_entity(default_attrib_name):
     "Convert the name of a default attrib to the entity where it is defined on"
     entities = zope.component.getUtility(
