@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009 Michael Howitz
+# Copyright (c) 2009-2011 Michael Howitz
 # See also LICENSE.txt
-
 import unittest
 from icemac.addressbook.browser.file.file import cleanup_filename
-import icemac.addressbook.testing
 
 
 class Test_cleanup_filename(unittest.TestCase):
@@ -26,7 +24,3 @@ class Test_cleanup_filename(unittest.TestCase):
     def test_UNC_filename(self):
         self.assertEqual(
             'sample.txt', cleanup_filename(r'\\server\mine\sample.txt'))
-
-
-def test_suite():
-    return icemac.addressbook.testing.UnittestSuite(Test_cleanup_filename)
