@@ -1,9 +1,8 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2010 Michael Howitz
+# Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: base.py 1183 2010-11-23 17:17:09Z icemac $
-
-from icemac.addressbook.i18n import MessageFactory as _
+# $Id: base.py 1370 2011-11-03 19:36:53Z icemac $
+from icemac.addressbook.i18n import _
 import icemac.addressbook.browser.search.interfaces
 import z3c.form.button
 import z3c.form.field
@@ -11,9 +10,18 @@ import z3c.formui.form
 import zope.interface
 
 
-class BaseView(object):
+class BaseView(zope.publisher.browser.BrowserView):
+    """Base class for search views.
+
+    Needs to extend from `zope.publisher.browser.BrowserView` as otherwise
+    no search result handler can be found (the machinery expects this view
+    to provide IBrowserView).
+
+    """
+    form_explanation = u''  # description of the search form displayed below it
 
     search_params = None
+    show_headline = False
 
     @property
     def result(self):
@@ -28,7 +36,7 @@ class BaseView(object):
 
 class BaseSearchForm(z3c.formui.form.Form):
 
-    interface = None  # to be set in child class
+    interface = NotImplemented  # to be set in child class
 
     ignoreContext = True
     formErrorsMessage = _('There were some errors.')
