@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: interfaces.py 1229 2011-01-29 17:07:16Z icemac $
+# $Id: interfaces.py 1277 2011-07-14 20:15:00Z icemac $
 
 import zope.interface
 
@@ -9,9 +9,6 @@ import zope.interface
 class IExporter(zope.interface.Interface):
     """Exporting facility."""
 
-    title = zope.interface.Attribute(u'Title of the exporter.')
-    description = zope.interface.Attribute(
-        u'Short description of the exporter.')
     file_extension = zope.interface.Attribute(
         u'Extension (without the leading dot!) to be set on export file name.')
     mime_type = zope.interface.Attribute(u'Mime-type of the export file.')
@@ -22,6 +19,3 @@ class IExporter(zope.interface.Interface):
         Returns a file or file-like-object.
 
         """
-
-    def __eq__(other):
-        """Checks whether two instances have the same class."""
