@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2010 Michael Howitz
+# Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: simple.py 1183 2010-11-23 17:17:09Z icemac $
+# $Id: simple.py 1277 2011-07-14 20:15:00Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import cStringIO
@@ -82,7 +82,7 @@ class XLSExport(icemac.addressbook.export.base.BaseExporter):
     def write_headlines(self, col, interface, headline):
         self.sheet.write(0, col, headline, group_style)
         fields = icemac.addressbook.interfaces.IEntity(
-            interface).getFieldValuesInOrder()
+            interface).getFieldValues()
         for field in fields:
             self.sheet.write(1, col, self.translate(field.title), head_style)
             col += 1
@@ -106,7 +106,7 @@ class XLSExport(icemac.addressbook.export.base.BaseExporter):
             return col
         idx = 0
         names_fields = icemac.addressbook.interfaces.IEntity(
-            interface).getFieldsInOrder()
+            interface).getFields()
         for name, field in names_fields:
             # Need to remove the security proxy to access the user
             # defined fields.
@@ -127,10 +127,7 @@ class XLSExport(icemac.addressbook.export.base.BaseExporter):
 
 
 class DefaultsExport(XLSExport):
-
-    title = _(u'XLS main')
-    description = _(
-        u'Exports person data and main addresses resp. phone numbers.')
+    """Exports person data and main addresses resp. phone numbers."""
 
     def _export(self):
         for entity in self.get_entities():
@@ -145,10 +142,7 @@ class DefaultsExport(XLSExport):
 
 
 class CompleteExport(XLSExport):
-
-    title = _(u'XLS complete')
-    description = _(
-        u'Exports person data and all addresses resp. phone numbers.')
+    """Exports person data and all addresses resp. phone numbers."""
 
     def _export(self):
         for entity in self.get_entities():
