@@ -4,27 +4,29 @@
 
 import doctest
 import icemac.addressbook.namechooser.namechooser
+import plone.testing
 import zope.annotation.attribute
 import zope.testing.cleanup
 import zope.testrunner.layer
 
 
-class NameChooserLayer(zope.testrunner.layer.UnitTests):
+class NameChooserLayer(plone.testing.Layer):
     """Layer for name chooser tests."""
+    defaultBases = (zope.testrunner.layer.UnitTests,)
 
-    @classmethod
-    def setUp(cls):
+    def setUp(self):
         zope.component.provideAdapter(
             zope.annotation.attribute.AttributeAnnotations)
         zope.component.provideAdapter(
             icemac.addressbook.namechooser.namechooser.name_suffix)
 
-    @classmethod
-    def tearDown(cls):
+    def tearDown(self):
         zope.testing.cleanup.tearDown()
 
+NAME_CHOOSER_LAYER = NameChooserLayer()
+
 
 def test_suite():
     suite = doctest.DocFileSuite('namechooser.txt')
-    suite.layer = NameChooserLayer
+    suite.layer = NAME_CHOOSER_LAYER
     return suite
