@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2008-2010 Michael Howitz
+# Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 1183 2010-11-23 17:17:09Z icemac $
+# $Id: tests.py 1265 2011-03-21 16:58:03Z icemac $
 
 import gocept.reference.verify
 import icemac.addressbook.principals.interfaces
@@ -12,6 +12,7 @@ import zope.interface.verify
 
 
 class TestInterfaces(unittest.TestCase):
+    layer = icemac.addressbook.testing.ADDRESS_BOOK_UNITTESTS
 
     def test_principal(self):
         principal = icemac.addressbook.principals.principals.Principal()
@@ -26,7 +27,3 @@ class TestInterfaces(unittest.TestCase):
             principal)
         zope.interface.verify.verifyObject(
             icemac.addressbook.principals.interfaces.IRoles, principal)
-
-
-def test_suite():
-    return icemac.addressbook.testing.AddressBookUnittestSuite(TestInterfaces)
