@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2009-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: testing.py 1242 2011-02-03 19:32:44Z icemac $
+# $Id: testing.py 1370 2011-11-03 19:36:53Z icemac $
 
 import gocept.selenium.grok
 import icemac.addressbook.address
@@ -12,96 +12,242 @@ import icemac.addressbook.keyword
 import icemac.addressbook.person
 import icemac.addressbook.principals.principals
 import icemac.addressbook.principals.sources
+import icemac.addressbook.startup
 import icemac.addressbook.utils
 import inspect
 import os
 import os.path
+import plone.testing
+import plone.testing.zca
+import plone.testing.zodb
 import re
 import tempfile
-import unittest
+import transaction
 import z3c.etestbrowser.wsgi
 import zope.annotation.attribute
+import zope.app.publication.httpfactory
+import zope.app.publication.zopepublication
 import zope.app.wsgi.testlayer
 import zope.component
+import zope.component.hooks
+import zope.event
+import zope.lifecycleevent
+import zope.processlifetime
 import zope.site.hooks
 import zope.testbrowser.browser
 import zope.testbrowser.interfaces
+import zope.testbrowser.wsgi
 import zope.testing.cleanup
 import zope.testing.renormalizing
 import zope.testrunner.layer
 
+
 if os.environ.get('ZOPETESTINGDOCTEST'):  # pragma: no cover
     from zope.testing import doctest
 else:
     import doctest
 
 
-class AddressBookUnitTests(zope.testrunner.layer.UnitTests):
+class _AddressBookUnitTests(plone.testing.Layer):
     """Layer for gathering addressbook unit tests."""
+    defaultBases = (zope.testrunner.layer.UnitTests,)
 
-    @classmethod
-    def setUp(cls):
+    def setUp(self):
         # Some classes use gocept.reference and store default values for
         # which annotations are needed.
         zope.component.provideAdapter(
             zope.annotation.attribute.AttributeAnnotations)
 
-    @classmethod
-    def tearDown(cls):
+    def tearDown(self):
         zope.testing.cleanup.tearDown()
 
-
-def UnittestSuite(*classes):
-    """Create a unittest test suite from unittest test classes."""
-    suite = unittest.TestSuite()
-    for class_ in classes:
-        suite.addTest(unittest.makeSuite(class_))
-    return suite
+ADDRESS_BOOK_UNITTESTS = _AddressBookUnitTests(name='AddressBookUnitTests')
 
 
-def AddressBookUnittestSuite(*classes):
-    """Create a unittest test suite on addressbook layer."""
-    suite = UnittestSuite(*classes)
-    suite.layer = AddressBookUnitTests
-    return suite
+class _ZCMLAndZODBLayer(plone.testing.zodb.EmptyZODB):
+    """Layer which sets up ZCML and ZODB to be useable for Zope 3."""
+    defaultBases = (plone.testing.zca.LAYER_CLEANUP,)
+
+    package = icemac.addressbook
+
+    def setUp(self):
+        super(_ZCMLAndZODBLayer, self).setUp()
+        plone.testing.zca.setUpZcmlFiles(
+            [("ftesting.zcml", self.package)])
+        zope.event.notify(zope.processlifetime.DatabaseOpened(self['zodbDB']))
+        transaction.commit()
+
+    def tearDown(self):
+        plone.testing.zca.tearDownZcmlFiles()
+        super(_ZCMLAndZODBLayer, self).tearDown()
+
+    def testSetUp(self):
+        pass
+
+    def testTearDown(self):
+        pass
+
+
+ZCML_AND_ZODB_LAYER = _ZCMLAndZODBLayer(name='ZCMLAndZODBLayer')
+
+
+def setUpStackedDemoStorage(self, name):
+    self['zodbDB'] = plone.testing.zodb.stackDemoStorage(
+        self['zodbDB'], name=name)
+
+
+def createZODBConnection(zodbDB):
+    connection = zodbDB.open()
+    zodbRoot = connection.root()
+    rootFolder = zodbRoot[
+        zope.app.publication.zopepublication.ZopePublication.root_name]
+    return connection, zodbRoot, rootFolder
+
+
+def setUpZODBConnection(self):
+    self['zodbConnection'], self['zodbRoot'], self['rootFolder'] = (
+        createZODBConnection(self['zodbDB']))
+    transaction.begin()
+
+
+def tearDownZODBConnection(self):
+    del self['rootFolder']
+    transaction.abort()
+    self['zodbConnection'].close()
+    del self['zodbConnection']
+    del self['zodbRoot']
+
+
+def tearDownStackedDemoStorage(self):
+    self['zodbDB'].close()
+    del self['zodbDB']
+
+
+class _ZODBTestLayer(plone.testing.Layer):
+    """Layer which opens the ZODB for each test."""
+    defaultBases = (ZCML_AND_ZODB_LAYER,)
+
+    def testSetUp(self):
+        setUpZODBConnection(self)
+
+    def testTearDown(self):
+        tearDownZODBConnection(self)
+
+FUNCTIONAL_LAYER = _ZODBTestLayer(name='ZODBTestLayer')
+
+
+class _ZODBIsolatedTestLayer(plone.testing.Layer):
+    """Layer which puts a DemoStorage on ZODB for each test."""
+    defaultBases = (ZCML_AND_ZODB_LAYER,)
+
+    def testSetUp(self):
+        setUpStackedDemoStorage(self, self.__name__)
+        setUpZODBConnection(self)
+
+    def testTearDown(self):
+        tearDownStackedDemoStorage(self)
+        tearDownZODBConnection(self)
+
+ZODB_ISOLATED_TEST_LAYER = _ZODBIsolatedTestLayer(name='ZODBIsolatedTestLayer')
+
+
+class WSGILayer(plone.testing.Layer):
+    """Layer which sets up a WSGI stack."""
+    defaultBases = (ZODB_ISOLATED_TEST_LAYER,)
+
+    def get_wsgi_pipeline(self):
+        return icemac.addressbook.startup.application_factory(
+            {}, db=self['zodbDB'])
+
+    def setUp(self):
+        self['wsgi_app'] = self.get_wsgi_pipeline()
+
+    def tearDown(self):
+        del self['wsgi_app']
+
+WSGI_LAYER = WSGILayer()
+
+
+class _WSGITestBrowserLayer(zope.testbrowser.wsgi.Layer,
+                            plone.testing.Layer):
+    """Layer for zope.testbrowser.wsgi tests."""
+    defaultBases = (WSGI_LAYER,)
+
+    def make_wsgi_app(self):
+        def getRootFolder():
+            return self['rootFolder']
+        # We could use zope.app.wsgi.testlayer.BrowserLayer but it extends
+        # ZODBLayer which we do not want as a base class, so we have to
+        # duplicate its middleware stack here:
+        return zope.testbrowser.wsgi.AuthorizationMiddleware(
+            zope.app.wsgi.testlayer.TransactionMiddleware(
+                getRootFolder, self['wsgi_app']))
+
+    def testSetUp(self):
+        # WSGI app stores the database at layer set up but we get a new
+        # database at test set up, so we have to set the right ZODB here:
+        self['wsgi_app'].requestFactory = (
+            zope.app.publication.httpfactory.HTTPPublicationRequestFactory(
+                self['zodbDB']))
+
+
+WSGI_TEST_BROWSER_LAYER = _WSGITestBrowserLayer(name='WSGITestBrowserLayer')
 
 
-FunctionalLayer = zope.app.wsgi.testlayer.BrowserLayer(icemac.addressbook)
 SeleniumLayer = gocept.selenium.grok.Layer(
     icemac.addressbook, name='SeleniumLayer')
 
 
-class FunctionalTestCase(unittest.TestCase):
-    """Base class for functional tests."""
-
-    layer = FunctionalLayer
+def setUpAddressBook(self):
+    self.old_site = zope.site.hooks.getSite()
+    conn, rootObj, rootFolder = createZODBConnection(self['zodbDB'])
+    addressbook = create_addressbook(parent=rootFolder)
+    zope.site.hooks.setSite(addressbook)
+    transaction.commit()
+    conn.close()
+    return addressbook
 
 
-class AddressBookFunctionalTestCase(FunctionalTestCase):
-    "Functional test case where the address book gets created in the set up."
+class _AddressBookFunctionalLayer(plone.testing.Layer):
+    "Layer where the address book gets created in the layer set up."
+    defaultBases = (ZCML_AND_ZODB_LAYER,)
 
     def setUp(self):
-        super(AddressBookFunctionalTestCase, self).setUp()
-        self.old_site = zope.site.hooks.getSite()
-        zope.site.hooks.setSite(
-            icemac.addressbook.testing.create_addressbook(
-                parent=self.layer.getRootFolder()))
+        setUpStackedDemoStorage(self, 'AddressBookFunctionalTestCase')
+        self['addressbook'] = setUpAddressBook(self)
 
     def tearDown(self):
-        super(AddressBookFunctionalTestCase, self).tearDown()
         zope.site.hooks.setSite(self.old_site)
+        del self['addressbook']
+        tearDownStackedDemoStorage(self)
+
+    def testSetUp(self):
+        setUpZODBConnection(self)
+        zope.site.hooks.setSite(self['addressbook'])
+
+    def testTearDown(self):
+        tearDownZODBConnection(self)
+
+ADDRESS_BOOK_FUNCTIONAL_LAYER = _AddressBookFunctionalLayer(
+    name='AddressBookFunctionalLayer')
 
 
-def FunctionalDocFileSuite(*paths, **kw):
+# Layer to use ADDRESS_BOOK_FUNCTIONAL_LAYER with testbrowser:
+WSGI_ADDRESS_BOOK_FUNCTIONAL_LAYER = _WSGITestBrowserLayer(
+    bases=[WSGILayer(bases=[ZODB_ISOLATED_TEST_LAYER,
+                            ADDRESS_BOOK_FUNCTIONAL_LAYER],
+                     name='WSGIAddressBookFunctionalLayer')],
+    name='TestBrowserAddressBookFunctionalLayer')
+
+
+def DocFileSuite(*paths, **kw):
+    """Project specific DocFileSuite."""
     kw['optionflags'] = (kw.get('optionflags', 0) |
                          doctest.ELLIPSIS |
                          doctest.NORMALIZE_WHITESPACE)
-    if 'layer' in kw:
-        layer = kw.pop('layer')
-    else:
-        layer = FunctionalLayer
+    layer = kw.pop('layer')
     globs = kw.setdefault('globs', {})
-    globs['getRootFolder'] = layer.getRootFolder
+    globs['layer'] = layer
     if 'checker' not in kw:
         kw['checker'] = zope.testing.renormalizing.RENormalizing([
             (re.compile(r'[0-9]{2}/[0-9]{2}/[0-9]{2} [0-9]{2}:[0-9]{2}'),
@@ -112,6 +258,17 @@ def FunctionalDocFileSuite(*paths, **kw):
     return suite
 
 
+def FunctionalDocFileSuite(*paths, **kw):
+    """DocFileSuite on FUNCTIONAL_LAYER."""
+    return DocFileSuite(layer=FUNCTIONAL_LAYER, *paths, **kw)
+
+
+def TestBrowserDocFileSuite(*paths, **kw):
+    """DocFileSuite on WSGI_TEST_BROWSER_LAYER."""
+    return DocFileSuite(layer=WSGI_TEST_BROWSER_LAYER, *paths, **kw)
+
+
+# XXX see https://sourceforge.net/tracker/?func=detail&aid=3381282&group_id=273840&atid=2319598
 def _get_control_names(interface, browser=None, form=None):
     """Get a sorted list of names of controls providing the given interface.
 
@@ -183,6 +340,21 @@ def write_temp_file(content, suffix):
     return file(filename, 'r'), os.path.basename(filename)
 
 
+# List of known users which are able to login using basic auth:
+USERNAME_PASSWORD_MAP = dict(mgr='mgrpw', editor='editor', visitor='visitor')
+
+
+class Browser(z3c.etestbrowser.wsgi.ExtendedTestBrowser):
+    """Customized browser which provides login."""
+
+    def login(self, username):
+        """Login a user using basic auth."""
+        self.addHeader('Authorization', 'Basic %s:%s' %
+                       (username, USERNAME_PASSWORD_MAP[username]))
+
+    get_messages = get_messages
+
+
 ### Helper functions to create objects in the database ###
 
 
@@ -194,18 +366,20 @@ def create_addressbook(name='ab', title=u'test address book', parent=None):
     """
     ab = icemac.addressbook.utils.create_obj(
         icemac.addressbook.addressbook.AddressBook, title=title)
-    frame = inspect.currentframe()
     if parent is None:
+        frame = inspect.currentframe()
         try:
-            parent = frame.f_back.f_globals['getRootFolder']()
+            parent = frame.f_back.f_globals['layer']['rootFolder']
         finally:
             del frame
     parent[name] = ab
     return ab
 
 
-def create_keyword(addressbook, title, return_obj=True):
-    parent = addressbook.keywords
+@icemac.addressbook.utils.set_site
+def create_keyword(title, return_obj=True):
+    """Create a new keyword."""
+    parent = zope.component.hooks.getSite().keywords
     name = icemac.addressbook.utils.create_and_add(
         parent, icemac.addressbook.keyword.Keyword, title=title)
     if return_obj:
@@ -300,7 +474,7 @@ def create(
     parent, entity_name, return_obj=False, set_as_default=False, *args, **kw):
     """Create an object using an entity.
 
-    entity_name ... module name and class name of entity
+    entity_name ... IEntity.class_name
 
     """
     entity = zope.component.getUtility(
@@ -315,6 +489,7 @@ def create(
     if set_as_default:
         field = icemac.addressbook.person.get_default_field(entity.interface)
         field.set(parent, obj)
+    zope.lifecycleevent.modified(obj)
     if return_obj:
         return obj
 
@@ -342,12 +517,16 @@ def create_user(ab, first_name, last_name, email, password, roles, **kw):
 def create_field(entity_name, type, title, **kw):
     """Create a user defined field for an entity.
 
-    entity_name ... module name and class name of entity
-    type ... see values of sources.FieldTypeSource
+    entity_name ... IEntity.class_name
+    type ... see values of .sources.FieldTypeSource
+
+    Returns the name of the created field.
+
+    To create values for a Choice field use: values=<list of values>
 
     """
     field = icemac.addressbook.utils.create_obj(
         icemac.addressbook.entities.Field, type=type, title=title, **kw)
     entity = zope.component.getUtility(
         icemac.addressbook.interfaces.IEntity, name=entity_name)
-    entity.addField(field)
+    return entity.addField(field)
